@@ -2,7 +2,7 @@
  *
  * pgut-list.c : copied from postgres/nodes/list.c
  *
- * Copyright (c) 2009-2011, NIPPON TELEGRAPH AND TELEPHONE CORPORATION
+ * Copyright (c) 2009-2012, NIPPON TELEGRAPH AND TELEPHONE CORPORATION
  * Portions Copyright (c) 1996-2009, PostgreSQL Global Development Group
  * Portions Copyright (c) 1994, Regents of the University of California
  *
@@ -265,6 +265,7 @@ list_nth_cell(List *list, int n)
 	return match;
 }
 
+#if PG_VERSION_NUM < 90200
 /*
  * Return the data value contained in the n'th element of the
  * specified list. (List elements begin at 0.)
@@ -275,7 +276,9 @@ list_nth(List *list, int n)
 	Assert(IsPointerList(list));
 	return lfirst(list_nth_cell(list, n));
 }
+#endif
 
+#if PG_VERSION_NUM < 90200
 /*
  * Return true iff 'datum' is a member of the list. Equality is
  * determined by using simple pointer comparison.
@@ -295,6 +298,7 @@ list_member_ptr(List *list, void *datum)
 
 	return false;
 }
+#endif
 
 /*
  * Delete 'cell' from 'list'; 'prev' is the previous element to 'cell'
@@ -407,6 +411,7 @@ list_free_deep(List *list)
 	list_destroy(list, free);
 }
 
+#if PG_VERSION_NUM < 90200
 /*
  * Return a shallow copy of the specified list.
  */
@@ -448,7 +453,9 @@ list_copy(List *oldlist)
 
 	return newlist;
 }
+#endif
 
+#if PG_VERSION_NUM < 90200
 /*
  * Return a shallow copy of the specified list, without the first N elements.
  */
@@ -500,6 +507,7 @@ list_copy_tail(List *oldlist, int nskip)
 
 	return newlist;
 }
+#endif
 
 #if !defined(USE_INLINE) && PG_VERSION_NUM < 90000 && !defined(__GNUC__)
 
